Description Usage Arguments See Also Examples
retrieves data from webpage and use caching mechanism to retrieve data from cache if run more than once
1 |
url |
url of webpage to retrieve |
... |
check |
headers |
list/json format input for custom headers |
cached |
returns a updated result if cached = FALSE |
1 2 3 4 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.